# -*- coding: utf-8 -*-

"""Top-level package for PyParallel."""

__author__ = """Joe Paul"""
__email__ = 'joeirimpan@gmail.com'
__version__ = '0.2.1'


from .pyparallel import Downloader  # noqa
from .cli import cli  # noqa
